==> kubernetes-model-1.0.53-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class DeploymentCauseBuilder extends DeploymentCauseFluentImpl<DeploymentCauseBuilder> implements VisitableBuilder<DeploymentCause,DeploymentCauseBuilder>{

    DeploymentCauseFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentCauseBuilder(){
            this(true);
    }
    public DeploymentCauseBuilder(Boolean validationEnabled){
            this(new DeploymentCause(), validationEnabled);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentCause(), validationEnabled);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,DeploymentCause instance){
            this(fluent, instance, true);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,DeploymentCause instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withImageTrigger(instance.getImageTrigger()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentCauseBuilder(DeploymentCause instance){
            this(instance,true);
    }
    public DeploymentCauseBuilder(DeploymentCause instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withImageTrigger(instance.getImageTrigger()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentCause build(){
            DeploymentCause buildable = new DeploymentCause(fluent.getImageTrigger(),fluent.getType());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentCauseBuilder that = (DeploymentCauseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class DeploymentCauseBuilder extends DeploymentCauseFluentImpl<DeploymentCauseBuilder> implements VisitableBuilder<DeploymentCause,DeploymentCauseBuilder>{

    DeploymentCauseFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentCauseBuilder(){
            this(true);
    }
    public DeploymentCauseBuilder(Boolean validationEnabled){
            this(new DeploymentCause(), validationEnabled);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentCause(), validationEnabled);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,DeploymentCause instance){
            this(fluent, instance, true);
    }
    public DeploymentCauseBuilder(DeploymentCauseFluent<?> fluent,DeploymentCause instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withImageTrigger(instance.getImageTrigger()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentCauseBuilder(DeploymentCause instance){
            this(instance,true);
    }
    public DeploymentCauseBuilder(DeploymentCause instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withImageTrigger(instance.getImageTrigger()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentCause build(){
            DeploymentCause buildable = new DeploymentCause(fluent.getImageTrigger(),fluent.getType());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentCauseBuilder that = (DeploymentCauseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
